CompositeReconnectionPolicy class

A composite reconnection policy that combines multiple policies using a logical operator (AND/OR). This allows for complex reconnection logic by combining multiple conditions.

Implemented types

Constructors

CompositeReconnectionPolicy({required Operator operator, required List<AutomaticReconnectionPolicy> policies})
Creates a CompositeReconnectionPolicy.

Properties

hashCode → int
The hash code for this object.
no setterinherited
operator → Operator
The logical operator to use when combining policies (Operator.and or Operator.or).
final
policies → List<AutomaticReconnectionPolicy>
List of reconnection policies to evaluate.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

canBeReconnected() → bool
Determines whether the WebSocket should attempt to reconnect automatically.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited