ConnectUserDetailsRequest class

Annotations
  • @JsonSerializable.new(createFactory: false, includeIfNull: false)

Constructors

ConnectUserDetailsRequest({required String id, String? image, bool? invisible, String? language, String? name, Map<String, Object?>? custom})
const
ConnectUserDetailsRequest.fromUser(User user, {bool includeDetails = true})
Creates the details to send when connecting as user.
factory

Properties

custom → Map<String, Object?>?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
image → String?
final
invisible → bool?
final
language → String?
final
name → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited